==> tmgmt_smartling-8.x-3.8.tar.gz: tmgmt_smartling/tests/src/Kernel/RealTimeNotificationsTest.php <==
<?php

namespace Drupal\Tests\tmgmt_smartling\Kernel;

use Drupal\Tests\tmgmt\Kernel\TMGMTKernelTestBase;
use Smartling\Batch\BatchApi;
use Smartling\File\FileApi;

/**
 * Tests interaction between core and the plugins.
 *
 * @group tmgmt_smartling
 */
class RealTimeNotificationsTest extends TMGMTKernelTestBase {

  public static $modules = ['tmgmt_smartling', 'tmgmt_extension_suit', 'tmgmt_file', 'file'];

  private $apiWrapperMock;
  private $batchApiMock;
  private $fileApiMock;
  private $pluginMock;

  /**
   * {@inheritdoc}
   */
  function setUp() {
    parent::setUp();

    // Suppress deprecation errors.
    set_error_handler(function($errno, $errstr, $errfile, $errline) {
      if ($errno == E_USER_DEPRECATED) {
        return TRUE;
      }

      return FALSE;
    });

    $this->installConfig(['tmgmt_smartling', 'tmgmt_extension_suit', 'tmgmt_file', 'file']);
    $this->installSchema('file', ['file_usage']);
    $this->installEntitySchema('file');

    $this->pluginMock = $this->getMockBuilder('\Drupal\tmgmt_smartling\Plugin\tmgmt_file\Format\Xml')
      ->setMethods(['validateImport', 'import'])
      ->getMock();

    $format_manager_mock = $this->getMockBuilder('\Drupal\tmgmt_file\Format\FormatManager')
      ->disableOriginalConstructor()
      ->setMethods(['createInstance'])
      ->getMock();

    $format_manager_mock->expects($this->any())
      ->method('createInstance')
      ->willReturn($this->pluginMock);

    $api_factory_mock = $this->getMockBuilder('\Drupal\tmgmt_smartling\Smartling\SmartlingApiFactory')
      ->setMethods(NULL)
      ->getMock();

    $logger_mock = $this->getMockBuilder('\Drupal\Core\Logger\LoggerChannel')
      ->setMethods(NULL)
      ->disableOriginalConstructor()
      ->getMock();

    $this->batchApiMock = $this->getMockBuilder(BatchApi::class)
      ->disableOriginalConstructor()
      ->getMock();

    $this->fileApiMock = $this->getMockBuilder(FileApi::class)
      ->disableOriginalConstructor()
      ->getMock();

    $this->apiWrapperMock = $this->getMockBuilder('\Drupal\tmgmt_smartling\Smartling\SmartlingApiWrapper')
      ->setMethods(['createFirebaseRecord', 'getApi', 'executeBatch'])
      ->setConstructorArgs([$api_factory_mock, $logger_mock])
      ->getMock();

    \Drupal::getContainer()->set('tmgmt_smartling.smartling_api_wrapper', $this->apiWrapperMock);
    \Drupal::getContainer()->set('plugin.manager.tmgmt_file.format', $format_manager_mock);
  }

  /**
   * {@inheritdoc}
   */
  protected function tearDown() {
    restore_error_handler();
  }

  /**
   * Creates a job.
   *
   * @param array $settings
   * @return \Drupal\tmgmt\JobInterface
   */
  function createJobWithItems(array $settings) {
    $job = parent::createJob();

    for ($i = 1; $i < 3; $i++) {
      $job->addItem('test_source', 'test', $i);
    }

    $job->translator = 'smartling';
    $job->settings = $settings;

    return $job;
  }

  /**
   * Upload success flow with batch execution.
   */
  function testRequestTranslationSuccessFlowExecute() {
    $this->apiWrapperMock->expects($this->once())
      ->method('getApi')
      ->with('batch')
      ->willReturn($this->batchApiMock);

    $this->apiWrapperMock->expects($this->at(1))
      ->method('createFirebaseRecord')
      ->with('tmgmt_smartling', 'notifications', 10, [
        "message" => 'File uploaded. Job id: 1, file name: JobID1_en_de.xml.',
        "type" => "status",
      ]);

    $this->apiWrapperMock->expects($this->at(3))
      ->method('createFirebaseRecord')
      ->with('tmgmt_smartling', 'notifications', 10, [
        "message" => "Finished: content is in the job. You may need to wait a few seconds before content is authorized (if you checked 'authorize' checkbox).",
        "type" => "status",
      ]);

    $translate_job = $this->createJobWithItems([
      'batch_uid' => 'uid',
      'batch_execute_on_job' => 1,
    ]);
    $translate_job->requestTranslation();
  }

  /**
   * Upload success flow without batch execution.
   */
  function testRequestTranslationSuccessFlowDoNotExecute() {
    $this->apiWrapperMock->expects($this->once())
      ->method('getApi')
      ->with('batch')
      ->willReturn($this->batchApiMock);

    $this->apiWrapperMock->expects($this->once())
      ->method('createFirebaseRecord')
      ->with('tmgmt_smartling', 'notifications', 10, [
        "message" => 'File uploaded. Job id: 1, file name: JobID1_en_de.xml.',
        "type" => "status",
      ]);

    $translate_job = $this->createJobWithItems([
      'batch_uid' => 'uid',
      'batch_execute_on_job' => 2,
    ]);
    $translate_job->requestTranslation();
  }

  /**
   * Upload fail flow: no batch uid.
   */
  function testRequestTranslationFailFlowNoBatchUid() {
    $this->apiWrapperMock->expects($this->once())
      ->method('createFirebaseRecord')
      ->with('tmgmt_smartling', 'notifications', 10, [
        "message" => "File JobID1_en_de.xml (job id = 1) wasn't uploaded. Please see logs for more info.",
        "type" => "error",
      ]);

    $translate_job = $this->createJobWithItems([]);
    $translate_job->requestTranslation();
  }

  /**
   * Upload fail flow: error while uploading.
   */
  function testRequestTranslationFailFlowErrorWhileUploading() {
    $this->apiWrapperMock->expects($this->once())
      ->method('getApi')
      ->with('batch')
      ->willReturn($this->batchApiMock);

    $this->apiWrapperMock->expects($this->once())
      ->method('executeBatch')
      ->will($this->throwException(new \Exception("Test")));

    $this->apiWrapperMock->expects($this->at(1))
      ->method('createFirebaseRecord')
      ->with('tmgmt_smartling', 'notifications', 10, [
        "message" => 'File uploaded. Job id: 1, file name: JobID1_en_de.xml.',
        "type" => "status",
      ]);

    $this->apiWrapperMock->expects($this->at(3))
      ->method('createFirebaseRecord')
      ->with('tmgmt_smartling', 'notifications', 10, [
        "message" => 'Error while uploading public://tmgmt_sources/JobID1_en_de.xml. Please see logs for more info.',
        "type" => "error",
      ]);

    $translate_job = $this->createJobWithItems([
      'batch_uid' => 'uid',
      'batch_execute_on_job' => 1,
    ]);
    $translate_job->requestTranslation();
  }

  /**
   * Download success full flow.
   */
  public function testDownloadSuccessFullFlow() {
    $this->apiWrapperMock->expects($this->once())
      ->method('getApi')
      ->with('file')
      ->willReturn($this->fileApiMock);

    $this->fileApiMock->expects($this->once())
      ->method('downloadFile')
      ->willReturn('xml');

    $this->pluginMock->expects($this->once())
      ->method('validateImport')
      ->willReturn(TRUE);

    $this->pluginMock->expects($this->once())
      ->method('import')
      ->willReturn([]);

    $this->apiWrapperMock->expects($this->once())
      ->method('createFirebaseRecord')
      ->with('tmgmt_smartling', 'notifications', 10, [
        "message" => 'Translation for "public://tmgmt_smartling_translations/JobID1_en_de.xml" (job id = 1) was successfully downloaded and imported.',
        "type" => "status",
      ]);

    $translate_job = $this->createJobWithItems([
      'batch_uid' => 'uid',
      'batch_execute_on_job' => 1,
    ]);
    tmgmt_smartling_download_file($translate_job);
  }

  /**
   * Download success partial flow: import skipped.
   */
  public function testDownloadSuccessPartialFlowImportSkipped() {
    $this->apiWrapperMock->expects($this->once())
      ->method('getApi')
      ->with('file')
      ->willReturn($this->fileApiMock);

    $this->fileApiMock->expects($this->once())
      ->method('downloadFile')
      ->willReturn('xml');

    $this->pluginMock->expects($this->once())
      ->method('validateImport')
      ->willReturn(TRUE);

    $this->apiWrapperMock->expects($this->once())
      ->method('createFirebaseRecord')
      ->with('tmgmt_smartling', 'notifications', 10, [
        "message" => 'Translation for "public://tmgmt_smartling_translations/JobID1_en_de.xml" (job id = 1) was successfully downloaded but import was skipped: downloaded and existing translations are equal.',
        "type" => "warning",
      ]);

    $translate_job = $this->createJobWithItems([
      'batch_uid' => 'uid',
      'batch_execute_on_job' => 1,
    ]);
    $translate_job->set('job_file_content_hash', '0f635d0e0f3874fff8b581c132e6c7a7');
    $translate_job->save();
    tmgmt_smartling_download_file($translate_job);
  }

  /**
   * Download fail flow.
   */
  public function testDownloadFailFlow() {
    $this->apiWrapperMock->expects($this->once())
      ->method('getApi')
      ->with('file')
      ->willReturn($this->fileApiMock);

    $this->fileApiMock->expects($this->once())
      ->method('downloadFile')
      ->will($this->throwException(new \Exception("Test")));

    $this->apiWrapperMock->expects($this->once())
      ->method('createFirebaseRecord')
      ->with('tmgmt_smartling', 'notifications', 10, [
        "message" => 'File JobID1_en_de.xml (job id = 1) wasn\'t downloaded. Please see logs for more info.',
        "type" => "error",
      ]);

    $translate_job = $this->createJobWithItems([
      'batch_uid' => 'uid',
      'batch_execute_on_job' => 1,
    ]);
    tmgmt_smartling_download_file($translate_job);
  }

  /**
   * Download fail flow: validation failed.
   */
  public function testDownloadFailFlowValidationFailed() {
    $this->apiWrapperMock->expects($this->once())
      ->method('getApi')
      ->with('file')
      ->willReturn($this->fileApiMock);

    $this->fileApiMock->expects($this->once())
      ->method('downloadFile')
      ->willReturn('xml');

    $this->pluginMock->expects($this->once())
      ->method('validateImport')
      ->willReturn(FALSE);

    $this->apiWrapperMock->expects($this->once())
      ->method('createFirebaseRecord')
      ->with('tmgmt_smartling', 'notifications', 10, [
        "message" => 'Translation for "public://tmgmt_smartling_translations/JobID1_en_de.xml" (job id = 1) was successfully downloaded but validation failed. See logs for more info.',
        "type" => "error",
      ]);

    $translate_job = $this->createJobWithItems([
      'batch_uid' => 'uid',
      'batch_execute_on_job' => 1,
    ]);
    tmgmt_smartling_download_file($translate_job);
  }

  /**
   * Download fail flow: import failed.
   */
  public function testDownloadFailFlowImportFailed() {
    $this->apiWrapperMock->expects($this->once())
      ->method('getApi')
      ->with('file')
      ->willReturn($this->fileApiMock);

    $this->fileApiMock->expects($this->once())
      ->method('downloadFile')
      ->willReturn('xml');

    $this->pluginMock->expects($this->once())
      ->method('validateImport')
      ->willReturn(TRUE);

    $this->pluginMock->expects($this->once())
      ->method('import')
      ->will($this->throwException(new \Exception("Test")));

    $this->apiWrapperMock->expects($this->once())
      ->method('createFirebaseRecord')
      ->with('tmgmt_smartling', 'notifications', 10, [
        "message" => 'Translation for "public://tmgmt_smartling_translations/JobID1_en_de.xml" (job id = 1) was successfully downloaded but import failed. See logs for more info.',
        "type" => "error",
      ]);

    $translate_job = $this->createJobWithItems([
      'batch_uid' => 'uid',
      'batch_execute_on_job' => 1,
    ]);
    tmgmt_smartling_download_file($translate_job);
  }
}

==> tmgmt_smartling-8.x-3.11.tar.gz: tmgmt_smartling/tests/src/Kernel/RealTimeNotificationsTest.php <==
<?php

namespace Drupal\Tests\tmgmt_smartling\Kernel;

use Drupal\Tests\tmgmt\Kernel\TMGMTKernelTestBase;
use Smartling\Batch\BatchApi;
use Smartling\File\FileApi;

/**
 * Tests interaction between core and the plugins.
 *
 * @group tmgmt_smartling
 */
class RealTimeNotificationsTest extends TMGMTKernelTestBase {

  public static $modules = ['tmgmt_smartling', 'tmgmt_extension_suit', 'tmgmt_file', 'file'];

  private $apiWrapperMock;
  private $batchApiMock;
  private $fileApiMock;
  private $pluginMock;

  /**
   * {@inheritdoc}
   */
  public function setUp() {
    parent::setUp();

    // Suppress deprecation errors.
    set_error_handler(function($errno, $errstr, $errfile, $errline) {
      if ($errno == E_USER_DEPRECATED) {
        return TRUE;
      }

      return FALSE;
    });

    $this->installConfig(['tmgmt_smartling', 'tmgmt_extension_suit', 'tmgmt_file', 'file']);
    $this->installSchema('file', ['file_usage']);
    $this->installEntitySchema('file');

    $this->pluginMock = $this->getMockBuilder('\Drupal\tmgmt_smartling\Plugin\tmgmt_file\Format\Xml')
      ->setMethods(['validateImport', 'import'])
      ->getMock();

    $format_manager_mock = $this->getMockBuilder('\Drupal\tmgmt_file\Format\FormatManager')
      ->disableOriginalConstructor()
      ->setMethods(['createInstance'])
      ->getMock();

    $format_manager_mock->expects($this->any())
      ->method('createInstance')
      ->willReturn($this->pluginMock);

    $api_factory_mock = $this->getMockBuilder('\Drupal\tmgmt_smartling\Smartling\SmartlingApiFactory')
      ->setMethods(NULL)
      ->getMock();

    $logger_mock = $this->getMockBuilder('\Drupal\Core\Logger\LoggerChannel')
      ->setMethods(NULL)
      ->disableOriginalConstructor()
      ->getMock();

    $this->batchApiMock = $this->getMockBuilder(BatchApi::class)
      ->disableOriginalConstructor()
      ->getMock();

    $this->fileApiMock = $this->getMockBuilder(FileApi::class)
      ->disableOriginalConstructor()
      ->getMock();

    $this->apiWrapperMock = $this->getMockBuilder('\Drupal\tmgmt_smartling\Smartling\SmartlingApiWrapper')
      ->setMethods(['createFirebaseRecord', 'getApi', 'executeBatch'])
      ->setConstructorArgs([$api_factory_mock, $logger_mock])
      ->getMock();

    \Drupal::getContainer()->set('tmgmt_smartling.smartling_api_wrapper', $this->apiWrapperMock);
    \Drupal::getContainer()->set('plugin.manager.tmgmt_file.format', $format_manager_mock);
  }

  /**
   * {@inheritdoc}
   */
  protected function tearDown() {
    restore_error_handler();
  }

  /**
   * Creates a job.
   *
   * @param array $settings
   * @return \Drupal\tmgmt\JobInterface
   */
  protected function createJobWithItems(array $settings) {
    $job = parent::createJob();

    for ($i = 1; $i < 3; $i++) {
      $job->addItem('test_source', 'test', $i);
    }

    $job->translator = 'smartling';
    $job->settings = $settings;

    return $job;
  }

  /**
   * Upload success flow with batch execution.
   */
  public function testRequestTranslationSuccessFlowExecute() {
    $this->apiWrapperMock->expects($this->once())
      ->method('getApi')
      ->with('batch')
      ->willReturn($this->batchApiMock);

    $this->apiWrapperMock->expects($this->at(1))
      ->method('createFirebaseRecord')
      ->with('tmgmt_smartling', 'notifications', 10, [
        "message" => 'File uploaded. Job id: 1, file name: JobID1_en_de.xml.',
        "type" => "status",
      ]);

    $this->apiWrapperMock->expects($this->at(3))
      ->method('createFirebaseRecord')
      ->with('tmgmt_smartling', 'notifications', 10, [
        "message" => "Finished: content is in the job. You may need to wait a few seconds before content is authorized (if you checked 'authorize' checkbox).",
        "type" => "status",
      ]);

    $translate_job = $this->createJobWithItems([
      'batch_uid' => 'uid',
      'batch_execute_on_job' => 1,
    ]);
    $translate_job->requestTranslation();
  }

  /**
   * Upload success flow without batch execution.
   */
  public function testRequestTranslationSuccessFlowDoNotExecute() {
    $this->apiWrapperMock->expects($this->once())
      ->method('getApi')
      ->with('batch')
      ->willReturn($this->batchApiMock);

    $this->apiWrapperMock->expects($this->once())
      ->method('createFirebaseRecord')
      ->with('tmgmt_smartling', 'notifications', 10, [
        "message" => 'File uploaded. Job id: 1, file name: JobID1_en_de.xml.',
        "type" => "status",
      ]);

    $translate_job = $this->createJobWithItems([
      'batch_uid' => 'uid',
      'batch_execute_on_job' => 2,
    ]);
    $translate_job->requestTranslation();
  }

  /**
   * Upload fail flow: no batch uid.
   */
  public function testRequestTranslationFailFlowNoBatchUid() {
    $this->apiWrapperMock->expects($this->once())
      ->method('createFirebaseRecord')
      ->with('tmgmt_smartling', 'notifications', 10, [
        "message" => "File JobID1_en_de.xml (job id = 1) wasn't uploaded. Please see logs for more info.",
        "type" => "error",
      ]);

    $translate_job = $this->createJobWithItems([]);
    $translate_job->requestTranslation();
  }

  /**
   * Upload fail flow: error while uploading.
   */
  public function testRequestTranslationFailFlowErrorWhileUploading() {
    $this->apiWrapperMock->expects($this->once())
      ->method('getApi')
      ->with('batch')
      ->willReturn($this->batchApiMock);

    $this->apiWrapperMock->expects($this->once())
      ->method('executeBatch')
      ->will($this->throwException(new \Exception("Test")));

    $this->apiWrapperMock->expects($this->at(1))
      ->method('createFirebaseRecord')
      ->with('tmgmt_smartling', 'notifications', 10, [
        "message" => 'File uploaded. Job id: 1, file name: JobID1_en_de.xml.',
        "type" => "status",
      ]);

    $this->apiWrapperMock->expects($this->at(3))
      ->method('createFirebaseRecord')
      ->with('tmgmt_smartling', 'notifications', 10, [
        "message" => 'Error while uploading public://tmgmt_sources/JobID1_en_de.xml. Please see logs for more info.',
        "type" => "error",
      ]);

    $translate_job = $this->createJobWithItems([
      'batch_uid' => 'uid',
      'batch_execute_on_job' => 1,
    ]);
    $translate_job->requestTranslation();
  }

  /**
   * Download success full flow.
   */
  public function testDownloadSuccessFullFlow() {
    $this->apiWrapperMock->expects($this->once())
      ->method('getApi')
      ->with('file')
      ->willReturn($this->fileApiMock);

    $this->fileApiMock->expects($this->once())
      ->method('downloadFile')
      ->willReturn('xml');

    $this->pluginMock->expects($this->once())
      ->method('validateImport')
      ->willReturn(TRUE);

    $this->pluginMock->expects($this->once())
      ->method('import')
      ->willReturn([]);

    $this->apiWrapperMock->expects($this->once())
      ->method('createFirebaseRecord')
      ->with('tmgmt_smartling', 'notifications', 10, [
        "message" => 'Translation for "public://tmgmt_smartling_translations/JobID1_en_de.xml" (job id = 1) was successfully downloaded and imported.',
        "type" => "status",
      ]);

    $translate_job = $this->createJobWithItems([
      'batch_uid' => 'uid',
      'batch_execute_on_job' => 1,
    ]);
    tmgmt_smartling_download_file($translate_job);
  }

  /**
   * Download success partial flow: import skipped.
   */
  public function testDownloadSuccessPartialFlowImportSkipped() {
    $this->apiWrapperMock->expects($this->once())
      ->method('getApi')
      ->with('file')
      ->willReturn($this->fileApiMock);

    $this->fileApiMock->expects($this->once())
      ->method('downloadFile')
      ->willReturn('xml');

    $this->pluginMock->expects($this->once())
      ->method('validateImport')
      ->willReturn(TRUE);

    $this->apiWrapperMock->expects($this->once())
      ->method('createFirebaseRecord')
      ->with('tmgmt_smartling', 'notifications', 10, [
        "message" => 'Translation for "public://tmgmt_smartling_translations/JobID1_en_de.xml" (job id = 1) was successfully downloaded but import was skipped: downloaded and existing translations are equal.',
        "type" => "warning",
      ]);

    $translate_job = $this->createJobWithItems([
      'batch_uid' => 'uid',
      'batch_execute_on_job' => 1,
    ]);
    $translate_job->set('job_file_content_hash', '0f635d0e0f3874fff8b581c132e6c7a7');
    $translate_job->save();
    tmgmt_smartling_download_file($translate_job);
  }

  /**
   * Download fail flow.
   */
  public function testDownloadFailFlow() {
    $this->apiWrapperMock->expects($this->once())
      ->method('getApi')
      ->with('file')
      ->willReturn($this->fileApiMock);

    $this->fileApiMock->expects($this->once())
      ->method('downloadFile')
      ->will($this->throwException(new \Exception("Test")));

    $this->apiWrapperMock->expects($this->once())
      ->method('createFirebaseRecord')
      ->with('tmgmt_smartling', 'notifications', 10, [
        "message" => 'File JobID1_en_de.xml (job id = 1) wasn\'t downloaded. Please see logs for more info.',
        "type" => "error",
      ]);

    $translate_job = $this->createJobWithItems([
      'batch_uid' => 'uid',
      'batch_execute_on_job' => 1,
    ]);
    tmgmt_smartling_download_file($translate_job);
  }

  /**
   * Download fail flow: validation failed.
   */
  public function testDownloadFailFlowValidationFailed() {
    $this->apiWrapperMock->expects($this->once())
      ->method('getApi')
      ->with('file')
      ->willReturn($this->fileApiMock);

    $this->fileApiMock->expects($this->once())
      ->method('downloadFile')
      ->willReturn('xml');

    $this->pluginMock->expects($this->once())
      ->method('validateImport')
      ->willReturn(FALSE);

    $this->apiWrapperMock->expects($this->once())
      ->method('createFirebaseRecord')
      ->with('tmgmt_smartling', 'notifications', 10, [
        "message" => 'Translation for "public://tmgmt_smartling_translations/JobID1_en_de.xml" (job id = 1) was successfully downloaded but validation failed. See logs for more info.',
        "type" => "error",
      ]);

    $translate_job = $this->createJobWithItems([
      'batch_uid' => 'uid',
      'batch_execute_on_job' => 1,
    ]);
    tmgmt_smartling_download_file($translate_job);
  }

  /**
   * Download fail flow: import failed.
   */
  public function testDownloadFailFlowImportFailed() {
    $this->apiWrapperMock->expects($this->once())
      ->method('getApi')
      ->with('file')
      ->willReturn($this->fileApiMock);

    $this->fileApiMock->expects($this->once())
      ->method('downloadFile')
      ->willReturn('xml');

    $this->pluginMock->expects($this->once())
      ->method('validateImport')
      ->willReturn(TRUE);

    $this->pluginMock->expects($this->once())
      ->method('import')
      ->will($this->throwException(new \Exception("Test")));

    $this->apiWrapperMock->expects($this->once())
      ->method('createFirebaseRecord')
      ->with('tmgmt_smartling', 'notifications', 10, [
        "message" => 'Translation for "public://tmgmt_smartling_translations/JobID1_en_de.xml" (job id = 1) was successfully downloaded but import failed. See logs for more info.',
        "type" => "error",
      ]);

    $translate_job = $this->createJobWithItems([
      'batch_uid' => 'uid',
      'batch_execute_on_job' => 1,
    ]);
    tmgmt_smartling_download_file($translate_job);
  }
}
